# Utilities for OneDep remote services

[![Build Status](https://dev.azure.com/wwPDB/wwPDB%20Python%20Projects/_apis/build/status/wwPDB.py-wwpdb_utils_ws_utils?branchName=master)](https://dev.azure.com/wwPDB/wwPDB%20Python%20Projects/_build/latest?definitionId=3&branchName=master)

## Introduction

This repository povides the tools pertaining to remote API services

### Installation

Download the library source software from the project repository:

```bash

git clone --recurse-submodules https://github.com/wwpdb/py-wwpdb_utils_ws_utils.git

```

Optionally, run test suite using the Tox test runner

```bash
tox
```


Installation is via the program [pip](https://pypi.python.org/pypi/pip).

```bash
pip install wwpdb.utils.ws_utils

or from the local repository:

pip install .
```
